@@ -67,7 +67,7 @@ def create_directory(directory_name: str) -> WorkingDir:
     """
     if directory_name is None or not directory_name:
         logging.error("Attempted to create directory with no name")
-        sys.exit(1)
+        raise SyntaxError("Attempted to create directory with no name")
     path = Path(rf"{directory_name}")
     logging.info(f"Trying to create {path}")
     os.mkdir(path)
@@ -119,8 +119,9 @@ def insert_on_db(
     table_name: str,
     data: List[Dict[str, Any]],
     truncate = False
-) -> bool:
-    """Genera la connessione al db PGSQL specificato ed esegue la query
+) -> None:
+    """Genera la connessione al db PGSQL specificato ed esegue la query.
+    Lancia un'eccezione in caso di errori lato db.
 
     Args:
         user (str): username
@@ -133,7 +134,7 @@ def insert_on_db(
         truncate (bool): default a False, parametro opzionale per decidere se fare la truncate o no della tabella
 
     Returns:
-        boolean: controllo per verificare se la scrittura è andata a buon fine o no
+        None
     """
     connection = None
     try:
@@ -150,11 +151,10 @@ def insert_on_db(
         logging.info(f"Queries executed")
     except Exception as error:
         logging.error(error)
-        return False
+        raise error
     finally:
         if connection is not None:
             connection.close()
-    return True
 
 
 def send_email(
@@ -164,7 +164,7 @@ def send_email(
 
     Args:
         subject (str): oggetto della mail
-        sender (str): mittende
+        sender (str): mittente
         receivers (List[str]): lista di destinatari
         text (str): testo della mail
         **kwargs: argomenti opzionali, vedi https://pypi.org/project/redmail/
